==> apimgmt-app-1.1.0-20251110.052729-39-sources.jar: com/digiwin/athena/apimgmt/dao/impl/mybatis/ApiMgmtStandardApiDataNameDaoMybatisImpl.java <==
package com.digiwin.athena.apimgmt.dao.impl.mybatis;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.IdUtil;
import com.digiwin.athena.apimgmt.dao.ApiMgmtStandardApiDataNameDao;
import com.digiwin.athena.apimgmt.dao.impl.mybatis.mapper.ApiMgmtStandardApiDataNameMapper;
import com.digiwin.athena.apimgmt.model.ProductApiDataName;
import com.digiwin.athena.apimgmt.model.StandardApiDataName;
import com.digiwin.athena.apimgmt.model.StandardApiVersion;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Primary
@Repository
public class ApiMgmtStandardApiDataNameDaoMybatisImpl extends GenericDaoMybatisImpl<ApiMgmtStandardApiDataNameMapper, StandardApiDataName, Integer>
        implements ApiMgmtStandardApiDataNameDao {

    protected ApiMgmtProductApiDataNameDaoMybatisImpl productApiDataNameDao;

    public ApiMgmtStandardApiDataNameDaoMybatisImpl() {
        super();
    }

    @Override
    public List<StandardApiDataName> getByApiVerId(Long pApiId, Boolean pShowField) {
        return baseMapper.getByApiVerId(pApiId, pShowField);
    }

    @Override
    public List<StandardApiDataName> getByApiVerIdAndMsgType(Long pApiId, Integer pMsgType, Boolean pShowField) {
        return baseMapper.getByApiVerIdAndMsgType(pApiId, pMsgType, pShowField);
    }

    @Override
    public List<StandardApiDataName> selectByVersionIds(List<Long> subIdList) {
        return baseMapper.selectByVersionIds(subIdList);
    }

    @Override
    public void batchSave(List<StandardApiDataName> list) {
        if (CollUtil.isEmpty(list)) {
            return;
        }

        setParentId(null, list);
        List<StandardApiDataName> allList = list.stream()
                .flatMap(StandardApiDataName::flatten).collect(Collectors.toList());

        List<ProductApiDataName> productApiDataNameList = allList.stream()
                .flatMap(v -> v.getProductApiDataNames().stream())
                .collect(Collectors.toList());


        CollUtil.split(allList, 200)
                .forEach(v -> baseMapper.insertList(v));
        productApiDataNameDao.batchSave(productApiDataNameList);
    }

    protected void setParentId(StandardApiDataName parent, List<StandardApiDataName> list) {
        if (parent != null && parent.getId() == null) {
            parent.setId(IdUtil.getSnowflakeNextId());
        }

        CollUtil.emptyIfNull(list).forEach(v -> {
            v.setParent(parent);
            setParentId(v, v.getChildrens());
        });

    }

    @Override
    public int deleteByApiVerId(Long apiVerId) {
        productApiDataNameDao.deleteByApiVerId(apiVerId);
        return baseMapper.deleteByApiVerId(apiVerId);
    }

    @Override
    public void fillStandardApiDataNames(List<StandardApiVersion> versions) {
        if (CollUtil.isEmpty(versions)) {
            return;
        }

        CollUtil.split(versions, 50).forEach(subList -> {
            List<Long> subIdList = subList.stream()
                    .map(StandardApiVersion::getId)
                    .collect(Collectors.toList());

            List<StandardApiDataName> dataNames = selectByVersionIds(subIdList);

            Map<Long, List<StandardApiDataName>> dataNameMap = dataNames.stream()
                    .collect(Collectors.groupingBy(StandardApiDataName::getApiVerId));

            subList.forEach(ver -> {
                List<StandardApiDataName> list = dataNameMap.get(ver.getId());

                if (CollUtil.isNotEmpty(list)) {
                    list.forEach(v -> v.setStandardApiVersion(ver));
                    ver.setStandardApiDataNames(list);
                }
            });

        });
    }


    @Autowired
    public void setProductApiDataNameMapper(ApiMgmtProductApiDataNameDaoMybatisImpl productApiDataNameDao) {
        this.productApiDataNameDao = productApiDataNameDao;
    }
}

==> apimgmt-app-1.1.0-20251125.015125-57-sources.jar: com/digiwin/athena/apimgmt/dao/impl/mybatis/ApiMgmtStandardApiDataNameDaoMybatisImpl.java <==
package com.digiwin.athena.apimgmt.dao.impl.mybatis;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.IdUtil;
import com.digiwin.athena.apimgmt.dao.ApiMgmtStandardApiDataNameDao;
import com.digiwin.athena.apimgmt.dao.impl.mybatis.mapper.ApiMgmtStandardApiDataNameMapper;
import com.digiwin.athena.apimgmt.model.ProductApiDataName;
import com.digiwin.athena.apimgmt.model.StandardApiDataName;
import com.digiwin.athena.apimgmt.model.StandardApiVersion;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Repository;

import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Primary
@Repository
public class ApiMgmtStandardApiDataNameDaoMybatisImpl extends GenericDaoMybatisImpl<ApiMgmtStandardApiDataNameMapper, StandardApiDataName, Integer>
        implements ApiMgmtStandardApiDataNameDao {

    protected ApiMgmtProductApiDataNameDaoMybatisImpl productApiDataNameDao;

    public ApiMgmtStandardApiDataNameDaoMybatisImpl() {
        super();
    }

    @Override
    public List<StandardApiDataName> getByApiVerId(Long pApiId, Boolean pShowField) {
        List<StandardApiDataName> list = baseMapper.getByApiVerId(pApiId, pShowField);
        productApiDataNameDao.fillProductDataName(list);
        return list;
    }

    @Override
    public List<StandardApiDataName> getByApiVerIdAndMsgType(Long pApiId, Integer pMsgType, Boolean pShowField) {
        return baseMapper.getByApiVerIdAndMsgType(pApiId, pMsgType, pShowField);
    }

    @Override
    public List<StandardApiDataName> selectByVersionIds(List<Long> subIdList) {
        return baseMapper.selectByVersionIds(CollUtil.distinct(subIdList));
    }

    @Override
    public void batchSave(List<StandardApiDataName> list) {
        if (CollUtil.isEmpty(list)) {
            return;
        }

        setParentId(null, list);
        List<StandardApiDataName> allList = list.stream()
                .flatMap(StandardApiDataName::flatten).collect(Collectors.toList());

        List<ProductApiDataName> productApiDataNameList = allList.stream()
                .flatMap(v -> v.getProductApiDataNames().stream())
                .collect(Collectors.toList());


        CollUtil.split(allList, 200)
                .forEach(v -> baseMapper.insertList(v));
        productApiDataNameDao.batchSave(productApiDataNameList);
    }

    protected void setParentId(StandardApiDataName parent, List<StandardApiDataName> list) {
        if (parent != null && parent.getId() == null) {
            parent.setId(IdUtil.getSnowflakeNextId());
        }

        CollUtil.emptyIfNull(list).forEach(v -> {
            v.setParent(parent);
            setParentId(v, v.getChildrens());
        });

    }

    @Override
    public int deleteByApiVerId(Long apiVerId) {
        productApiDataNameDao.deleteByApiVerId(apiVerId);
        return baseMapper.deleteByApiVerId(apiVerId);
    }

    @Override
    public void fillStandardApiDataNames(List<StandardApiVersion> versions) {
        if (CollUtil.isEmpty(versions)) {
            return;
        }

        CollUtil.split(versions, 50).forEach(subList -> {
            List<Long> subIdList = subList.stream()
                    .map(StandardApiVersion::getId).collect(Collectors.toList());

            List<StandardApiDataName> dataNames = selectByVersionIds(subIdList);

            Map<Long, List<StandardApiDataName>> dataNameMap = dataNames.stream()
                    .collect(Collectors.groupingBy(StandardApiDataName::getApiVerId));

            subList.forEach(ver -> {
                List<StandardApiDataName> list = dataNameMap.getOrDefault(ver.getId(), Collections.emptyList());

                list.forEach(v -> v.setStandardApiVersion(ver));
                ver.setStandardApiDataNames(list);
            });

        });
    }


    @Autowired
    public void setProductApiDataNameMapper(ApiMgmtProductApiDataNameDaoMybatisImpl productApiDataNameDao) {
        this.productApiDataNameDao = productApiDataNameDao;
    }
}
